@@ -16,10 +16,10 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 # project name
-APPLICATION="hertzbeat-collector"
+APPLICATION="hertzbeat-collector-collector"
 
 # jar file name
-APPLICATION_JAR="apache-hertzbeat-collector-1.6.0.jar"
+APPLICATION_JAR="apache-hertzbeat-collector-1.6.1.jar"
 
 # find the service pid, kill -9 pid
 PID=$(ps -ef | grep java | grep "${APPLICATION_JAR}" | grep -v grep | awk '{ print $2 }')
